/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user;

import java.util.Iterator;

import org.keycloak.admin.client.resource.RealmResource;
import org.keycloak.admin.client.resource.UsersResource;
import org.keycloak.representations.idm.UserRepresentation;

import com.cronutils.utils.StringUtils;

public class RemoteUserIterator implements Iterator<UserRepresentation> {

	private static final int PAGE_SIZE = 10;

	private final UsersResource users;
	private final int count;

	private int step = 0;
	private Iterator<UserRepresentation> loadedUserIterator;

	public RemoteUserIterator(RealmResource resource) {
		users = resource.users();
		count = users.count();
		loadNextStep();
	}

	@Override
	public boolean hasNext() {
		if (loadedUserIterator.hasNext()) {
			return true;
		}
		if (count > step * PAGE_SIZE) {
			loadNextStep();
			return loadedUserIterator.hasNext();
		}
		return false;
	}

	private void loadNextStep() {
		loadedUserIterator = users.search(StringUtils.EMPTY, step * PAGE_SIZE, ++step * PAGE_SIZE).iterator();
	}

	@Override
	public UserRepresentation next() {
		return loadedUserIterator.next();
	}
}