/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.keycloak;

import static org.mockito.Mockito.*;

import java.util.Optional;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.user.UserTestFactory;

class KeycloakUserRemoteServiceTest {

	@InjectMocks
	private KeycloakUserRemoteService remoteService;
	@Mock
	private KeycloakApiService apiService;

	@DisplayName("Get all users")
	@Nested
	class TestGetAllUsers {

		@Test
		void shouldCallApiService() {
			remoteService.getAllUsers();

			verify(apiService).findAllUser();
		}
	}

	@DisplayName("Update ozgCloudUserId attribute in keycloak")
	@Nested
	class TestUpdateOzgCloudUserId {

		@Test
		void shouldCallApiService() {
			remoteService.updateOzgCloudUserId(UserTestFactory.create());

			verify(apiService).updateAttribute(
					UserTestFactory.KEYCLOAK_USER_ID,
					KeycloakUserRemoteService.ATTRIBUTE_NAME_OZG_CLOUD_USER_ID,
					UserTestFactory.ID.toString());
		}
	}

	@Nested
	@DisplayName("Get user by id")
	class TestGetUser {

		private static final String USER_ID = "12345";

		@Test
		void shouldCallApiService() {
			when(apiService.findUserById(any())).thenReturn(Optional.of(UserTestFactory.create()));

			remoteService.findUserById(USER_ID);

			verify(apiService).findUserById(USER_ID);
		}
	}
}
